@@ -434,7 +434,7 @@ class Clock(object):
         self._time = None
         self.registry = dict()
         self.alarm_time = []
-        self.clients_to_wake_up = defaultdict(list)
+        self.clients_to_wake_up = defaultdict(set)
         self.last_required_alarm = -1
 
     @property
@@ -488,7 +488,7 @@ class Clock(object):
             self.registry[alarm_message.receiver] = registry
         registry.set_alarm(wakeup_time, alarm_message)
 
-        self.clients_to_wake_up[wakeup_time].append(alarm_message.receiver)
+        self.clients_to_wake_up[wakeup_time].add(alarm_message.receiver)
 
     def list_alarms(self, receiver):
         """ returns alarms set for uuid
